<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>DimRegen</name>
    <message>
        <location filename="../DimRegen.js" line="+64"/>
        <source>No dimension entities with custom label positions selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Label position of %n dimension(s) was reset.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../DimRegenInit.js" line="+2"/>
        <source>&amp;Reset Label Position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
